@@ -1,6 +1,7 @@
 import os
 import random
 import re
+import sys
 import time
 import logging
 import decimal
@@ -11,38 +12,98 @@ import json
 import difflib
 import time
 import logging
-from tipset.libs import rmt_ssh
+import argparse
+from functools import wraps
 from yaml import load, dump
 try:
     from yaml import CLoader as Loader, CDumper as Dumper
 except ImportError:
     from yaml import Loader, Dumper
 
-def init_ssh(params=None, timeout=600, log=None):
+LOG = logging.getLogger('os_tests.os_tests_run')
+logging.basicConfig(level=logging.INFO)
+
+def init_args():
+    parser = argparse.ArgumentParser(
+    description="os-tests is a lightweight, fast check and tests collection for Linux OS.")
+    parser.add_argument('-l', dest='is_listcase', action='store_true',
+                    help='list supported cases without run', required=False)
+    parser.add_argument('-p', dest='pattern', default=None, action='store',
+                    help='filter case by name, add --strict for matching exactly', required=False)
+    parser.add_argument('--strict', dest='is_strict', action='store_true',
+                    help='match exactly if -p or -s specified', required=False)
+    parser.add_argument('-s', dest='skip_pattern', default=None, action='store',
+                    help='skip cases, add --strict for skipping exactly', required=False)
+    parser.add_argument('--verifydoc', dest='verifydoc', action='store_true',
+                    help='verify or show case doc only', required=False)
+    parser.add_argument('--filter_by', dest='filter_by', default='case_name', action='store',
+                    help="filter by 'case_name'(default),'case_tag','case_file','component','bugzilla_id',\
+                        'is_customer_case','testplan','maintainer','description','key_steps',\
+                        'expect_result','debug_want'", required=False)
+    parser.add_argument('--host', dest='remote_node', default=None, action='store',
+                    help='run tests on remote node', required=False)
+    parser.add_argument('--port', dest='remote_port', default=22, action='store',
+                    help='port for ssh connection, default is 22', required=False)
+    parser.add_argument('--user', dest='remote_user', default=None, action='store',
+                    help='user to login to remote node', required=False)
+    parser.add_argument('--password', dest='remote_password', default=None, action='store',
+                    help='password to login to remote node', required=False)
+    parser.add_argument('--keyfile', dest='remote_keyfile', default=None, action='store',
+                    help='keyfile to login to remote node', required=False)
+    parser.add_argument('--result', dest='results_dir', default=None, action='store',
+                    help='save result to specific directory', required=False)
+    parser.add_argument('--image', dest='image', default=None, action='store',
+                    help='specify azure to run azure image check only', required=False)
+    parser.add_argument('--disks', dest='blk_devs', default=None, action='store',
+                    help='free disks for storage test, eg. "/dev/nvme0n1", data on disk has lost risks', required=False)
+    parser.add_argument('--platform_profile', dest='platform_profile', default=None, action='store',
+                    help='specify platform profile if enable os-tests provison vms self, only supports aws for now', required=False)
+    args = parser.parse_args()
+    return args
+
+def init_provider(params=None):
+    vm = None
+    if 'aws' in params['Cloud']['provider']:
+        from .resources_aws import EC2VM,EC2Volume
+        vm = EC2VM(params)
+        vm.create()
+        # init disk and do not create disk at very beginning
+        disk = EC2Volume(params)
+    if 'openstack' in params['Cloud']['provider']:
+        from .resources_openstack import OpenstackVM
+        vm = OpenstackVM(params)
+        vm.create()
+        disk = None
+    if 'ali' in params['Cloud']['provider']:
+        from .resources_alicloud import AlibabaVM
+        vm = AlibabaVM(params)
+        vm.create(wait=True)
+        if vm.is_stopped():
+            vm.start(wait=True)
+        disk = None
+    return vm, disk
+
+def init_ssh(params=None, timeout=600, interval=10, log=None):
+    from tipset.libs import rmt_ssh
     if log is None:
         LOG_FORMAT = '%(levelname)s:%(message)s'
         log = logging.getLogger(__name__)
         logging.basicConfig(level=logging.INFO, format=LOG_FORMAT)
     ssh = rmt_ssh.RemoteSSH()
     ssh.rmt_node = params['remote_node']
+    ssh.port = params['remote_port']
     ssh.rmt_user = params['remote_user']
     ssh.rmt_password = params['remote_password']
     ssh.rmt_keyfile = params['remote_keyfile']
     ssh.log = log
-    start_time = time.time()
-    while True:
-        current_time = time.time()
-        if current_time - start_time > timeout:
-            log.info("timeout to connect to remote")
-            return None
-        ssh.create_connection()
-        if ssh.ssh_client is not None:
-            return ssh
-        time.sleep(5)
-        log.info("Not conncted, retry again! timeout:{}".format(timeout))
+    ssh.timeout = timeout
+    ssh.interval = interval
+    ssh.create_connection()
+    if ssh.ssh_client is not None:
+        return ssh
     return None
 
-def init_connection(test_instance, timeout=600):
+def init_connection(test_instance, timeout=600, interval=10):
     if test_instance.params['remote_node'] is None:
         return
     test_instance.log.info("remote_node specified, all tests will be run in {}".format(test_instance.params['remote_node']))
@@ -57,20 +118,34 @@ def init_connection(test_instance, timeout=600):
         pass
     except Exception:
         test_instance.log.info("connection is not live")
-    test_instance.SSH = init_ssh(params=test_instance.params, timeout=timeout, log=test_instance.log)
+    test_instance.SSH = init_ssh(params=test_instance.params, timeout=timeout, interval=interval, log=test_instance.log)
     if test_instance.SSH is None:
         test_instance.skipTest("Cannot make ssh connection to remote, please check")
 
-def get_cfg():
+def get_cfg(cfg_file = None):
     # Config file
-    cfg_file = os.path.dirname(os_tests.__file__) + "/cfg/os-tests.yaml"
-    # Result dir
-    with open(cfg_file,'r') as fh:
-       keys_data = load(fh, Loader=Loader)
-    if os.path.exists(cfg_file):
-        print("{} config file found!".format(cfg_file))
+    if not cfg_file:
+        cfg_file = os.path.dirname(os_tests.__file__) + "/cfg/os-tests.yaml"
+    if not os.path.exists(cfg_file):
+        print("{} config file not found!".format(cfg_file))
+        sys.exit(1)
+        return cfg_file, None
+    keys_data = load_yaml(yaml_file=cfg_file)
     return cfg_file, keys_data
 
+def load_yaml(yaml_file = None, yaml_content = None):
+    keys_data = None
+    try:
+        if yaml_file:
+            with open(yaml_file,'r') as fh:
+                keys_data = load(fh, Loader=Loader)
+            return keys_data
+        if yaml_content:
+            keys_data = load(yaml_content,Loader=Loader)
+    except Exception as err:
+        print(err)
+    return keys_data
+
 def init_case(test_instance):
     """init case
     Arguments:
@@ -113,13 +188,21 @@ def init_case(test_instance):
         if  test_instance.SSH.ssh_client is None:
             test_instance.skipTest("Cannot make ssh connection to remote, please check")
     node_info = "{}/node_info".format(debug_dir)
+    node_info_data = {}
     if not os.path.exists(node_info):
         test_instance.log.info("retrive node info.")
-        release_name = get_os_release_info(test_instance, field="NAME")
-        release_version = get_os_release_info(test_instance, field="VERSION")
-        kernel_version = run_cmd(test_instance, 'uname -r')
+        node_info_data['release_name'] = get_os_release_info(test_instance, field="NAME").rstrip('\n| ')
+        node_info_data['release_version'] = get_os_release_info(test_instance, field="VERSION").rstrip('\n| ')
+        node_info_data['kernel_version'] = run_cmd(test_instance, 'uname -r').rstrip('\n| ')
+        node_info_data['product_name'] = run_cmd(test_instance, 'cat /sys/devices/virtual/dmi/id/product_name').rstrip('\n| ')
+        node_info_data['sys_vendor'] = run_cmd(test_instance, 'cat /sys/devices/virtual/dmi/id/sys_vendor').rstrip('\n| ')
+        #with open(node_info, 'w+') as fh:
+        #    fh.write("{} {} - {}".format(release_name, release_version, kernel_version))
         with open(node_info, 'w+') as fh:
-            fh.write("{} {} - {}".format(release_name, release_version, kernel_version))
+            dump(node_info_data,fh)
+        test_instance.node_info = node_info_data
+    else:
+        _, test_instance.node_info = get_cfg(cfg_file=node_info)
 
 def finish_case(test_instance):
     """finish case
@@ -128,6 +211,86 @@ def finish_case(test_instance):
     """
     pass
 
+def filter_case_doc(case=None, patterns=None, skip_patterns=None, filter_field='case_name', strict=False, verify_doc=False ):
+    if patterns is None and skip_patterns is None and not verify_doc:
+        return True
+    yaml_data = {}
+    yaml_fail = None
+    try:
+        yaml_data = load(case._testMethodDoc, Loader=Loader)
+        if not hasattr(yaml_data,'get'):
+            yaml_data = {}
+            yaml_data['case_name'] = case.id()
+        else:
+            yaml_data['case_name'] = case.id()
+    except Exception as err:
+        yaml_fail = err
+        yaml_data['case_name'] = case.id()
+    is_skip = False
+    is_select = False
+    field_value = yaml_data.get(filter_field)
+    if patterns:
+        for p in patterns.split(','):
+            if 'case_tag' in filter_field:
+                if not field_value:
+                    break
+                # case_tag might has multiples
+                for tag in field_value.split(','):
+                    if not strict and p in tag:
+                        is_select = True
+                        break
+                    if strict and p == tag:
+                        is_select = True
+                        break
+                if is_select:
+                    break
+            else:
+                if not strict and field_value and p in field_value:
+                    is_select = True
+                    break
+                if strict and field_value and p == field_value:
+                    is_select = True
+                    break
+    else:
+        is_select = True
+    if skip_patterns:
+        for p in skip_patterns.split(','):
+            if 'case_tag' in filter_field:
+                if not field_value:
+                    break
+                # case_tag might has multiples
+                for tag in field_value.split(','):
+                    if not strict and p in tag:
+                        is_skip = True
+                        break
+                    if strict and p == tag:
+                        is_skip = True
+                        break
+                if is_skip:
+                    break
+            else:
+                if not strict and field_value and p in field_value:
+                    is_skip = True
+                    break
+                if strict and field_value and p == field_value:
+                    is_skip = True
+                    break
+    if verify_doc and is_select and not is_skip:
+        expect_fields = ['case_tag','case_name','case_file','component','bugzilla_id',
+                        'is_customer_case','testplan','maintainer','description','key_steps',
+                        'expect_result','debug_want']
+        print("="*20)
+        print(case.id())
+        print(case._testMethodDoc)
+        print("-"*20)
+        if  yaml_fail:
+            print(yaml_fail)
+            return is_select and not is_skip
+        for i in expect_fields:
+            if not yaml_data.get(i):
+                print('missing {}'.format(i))
+    return is_select and not is_skip
+
 def msg_to_syslog(test_instance, msg=None):
     '''
     Save msg to journal log and dmesg.
@@ -241,6 +404,10 @@ def run_cmd(test_instance,
                    output = ret.stdout
         except Exception as err:
             test_instance.log.error("Run cmd failed again {}".format(err))
+    if status is None and test_instance.vm:
+        test_instance.vm.get_console_log()
+        test_instance.vm.stop()
+        test_instance.vm.start()
     if cursor is not None and cursor in output:
         output = output[output.index(cursor):]
     if is_log_output:
@@ -457,6 +624,25 @@ def is_ali(test_instance, action=None):
         test_instance.log.info("Not an ali system.")
     return False
 
+def is_openstack(test_instance, action=None):
+    '''
+    Check whether system is a openstack system.
+    Arguments:
+        test_instance {Test instance} -- unittest.TestCase instance
+        action {string} -- cancel case if it is not a ali system
+    Return:
+        openstack: return True
+        other: return False
+    '''
+    if 'OpenStack' in test_instance.node_info.get('product_name'):
+        test_instance.log.info("Openstack system.")
+        return True
+    else:
+        if action == "cancel":
+            test_instance.skipTest("Cancel it in non Openstack system.")
+        test_instance.log.info("Not an Openstack system.")
+    return False
+
 def is_metal(test_instance, action=None):
     '''
     Check whether system is a baremetal system.
@@ -534,17 +720,18 @@ def is_pkg_installed(test_instance, pkg_name=None, is_install=True, cancel_case=
         cmd {string} -- checked command
         is_install {bool} -- try to install it or not
     '''
-    cmd_check = "rpm -qa|grep {}".format(pkg_name)
-    ret = run_cmd(test_instance, cmd_check, ret_status=True)
+    cmd = "rpm -q {}".format(pkg_name)
+    ret = run_cmd(test_instance, cmd, ret_status=True)
     if ret == 0:
         return True
     else:
-        test_instance.log.info("No %s found!" % pkg_name)
+        test_instance.log.info("No {} found!".format(pkg_name))
         if is_install:
             cmd = 'sudo yum install -y {}'.format(pkg_name)
             ret = run_cmd(test_instance, cmd, ret_status=True, msg='try to install it', timeout=timeout)
             if ret == 0:
                 return True
+        if cancel_case: test_instance.skipTest("Unable to install {}".format(pkg_name))
         return False
 
 def pkg_install(test_instance, pkg_name=None, pkg_url=None, force=False):
@@ -606,6 +793,16 @@ def get_memsize(test_instance, action=None):
     test_instance.log.info("Total memory: {:0,.1f}GiB".format(mem_gb))
     return mem_gb
 
+def get_disk_online(test_instance):
+    '''
+    Get online disks in system.
+    '''
+    cmd = 'lsblk -d'
+    output = run_cmd(test_instance, cmd, expect_ret=0, msg='Get online disk count.')
+    count = output.count('disk') - output.count('SWAP')
+    test_instance.log.info('Online disks: %s' % count)
+    return count
+
 def get_cmd_cursor(test_instance, cmd='dmesg -T', rmt_redirect_stdout=False, rmt_get_pty=False, timeout=60):
     '''
     Get command cursor by last matched line.
@@ -649,7 +846,7 @@ def check_log(test_instance, log_keyword, log_cmd="journalctl -b 0", match_word_
     if match_word_exact:
         check_cmd = check_cmd + '|grep -iw %s' % log_keyword
     if skip_words:
-        check_cmd = check_cmd + '|grep -Ev "%{}"'.format(skip_words.replace(',','|'))
+        check_cmd = check_cmd + '|grep -Ev "{}"'.format(skip_words.replace(',','|'))
     ret = False
     if cursor is not None:
         out = run_cmd(test_instance,
@@ -760,11 +957,12 @@ def find_word(test_instance, check_str, log_keyword, baseline_dict=None, skip_wo
                             no_fail = False
                             check_done = True
                             break
-                        if baseline_dict[basekey]["trigger"] in check_str and len(baseline_dict[basekey]["trigger"]) > 3:
-                            test_instance.log.info("Guess it is expected because trigger keywords found '{}'".format(baseline_dict[basekey]["trigger"]))
+                        trigger = baseline_dict[basekey]["trigger"]
+                        if trigger and re.search(trigger,check_str,flags=re.I):
+                            test_instance.log.info("Guess it is expected because trigger keywords found '{}'".format(trigger))
                             find_it = True
-                        elif len(baseline_dict[basekey]["trigger"]) > 3:
-                            test_instance.log.info("Guess it is unexpected because trigger keywords not found '{}'".format(baseline_dict[basekey]["trigger"]))
+                        elif trigger:
+                            test_instance.log.info("Guess it is unexpected because trigger keywords not found '{}'".format(trigger))
                             find_it = False
                         test_instance.log.info("log:{}, base:{}".format(line1, sub_basekey_content))
                         test_instance.log.info("ID:%s Baseline analyze:%s Branch:%s Status:%s Link:%s Path:%s" %
@@ -796,11 +994,12 @@ def find_word(test_instance, check_str, log_keyword, baseline_dict=None, skip_wo
                               baseline_dict[basekey]["status"],
                               baseline_dict[basekey]["link"],
                               baseline_dict[basekey]["path"]))
-                    if baseline_dict[basekey]["trigger"] in check_str and len(baseline_dict[basekey]["trigger"]) > 3:
-                        test_instance.log.info("Guess it is expected because trigger keywords found '{}'".format(baseline_dict[basekey]["trigger"]))
+                    trigger = baseline_dict[basekey]["trigger"]
+                    if trigger and re.search(trigger,check_str,flags=re.I):
+                        test_instance.log.info("Guess it is expected because trigger keywords found '{}'".format(trigger))
                         find_it = True
-                    elif len(baseline_dict[basekey]["trigger"]) > 3:
-                        test_instance.log.info("Guess it is unexpected because trigger keywords not found '{}'".format(baseline_dict[basekey]["trigger"]))
+                    elif trigger:
+                        test_instance.log.info("Guess it is unexpected because trigger keywords not found '{}'".format(trigger))
                         find_it = False
                         break
                     if baseline_dict[basekey]["status"] == 'active':
@@ -842,4 +1041,54 @@ def set_service(test_instance, service="systemd-journald-audit.socket", enable_i
         if check_ret:
             run_cmd(test_instance,cmd['cmd'], expect_ret=0, msg=cmd['msg'])
         else:
-            run_cmd(test_instance,cmd['cmd'], msg=cmd['msg'])
\ No newline at end of file
+            run_cmd(test_instance,cmd['cmd'], msg=cmd['msg'])
+
+def wait_for(ret=None, not_ret=None, ck_ret=False, ck_not_ret=False, timeout=60, interval=1):
+    '''
+    wait for a func return expected value within specified time
+    '''
+    def decorate(func):
+        @wraps(func)
+        def wrapper(*args, **kwargs):
+            start_time = time.time()
+            while True:
+                LOG.info("{} called, timeout {}".format(func.__name__, timeout))
+                result = func(*args, **kwargs)
+                if ck_ret and result == ret:
+                    break
+                if ck_not_ret and not_ret != result:
+                    break
+                end_time = time.time()
+                time.sleep(interval)
+                if end_time - start_time > timeout:
+                    LOG.info('timeout, exit!')
+                    break
+            return result
+        return wrapper
+    return decorate
+
+def iterate_timeout(timeout, message, wait=2):
+    start = time.time()
+    count = 0
+    while (timeout is None) or (time.time() < start + timeout):
+        count += 1
+        yield count
+        logging.debug('Have been waiting for %ss/%ss.' %
+                      (int(time.time() - start), timeout))
+        time.sleep(wait)
+    raise TimeoutError(message)
+
+def get_value(x={}, key=None, path=None):
+    # walk through the dict and get key under parent path
+    ret = None
+    if path is None and isinstance(x,dict):
+        return x.get(key)
+    if isinstance(x,dict):
+        for i in x.keys():
+            if path == i:
+                if isinstance(x.get(i),dict):
+                    ret = x.get(i).get(key)
+                    break
+            else:
+                ret = get_value(x=x.get(i), key=key, path=path)
+    return ret
\ No newline at end of file
