@@ -24,32 +24,115 @@ class TestGeneralCheck(unittest.TestCase):
                 cmd = 'sudo rpm -V {} > {} 2>&1'.format(' '.join(check_list), rpm_V_file)
                 utils_lib.run_cmd(self, cmd, msg="verify pkgs", timeout=600)
                 self.output = utils_lib.run_cmd(self, 'cat {}'.format(rpm_V_file), expect_ret=0, msg="check if output exists again")
-        if self.id().endswith(('test_check_systemd_analyze_verify_missing', 'test_check_systemd_analyze_verify_deprecated_unsafe', 'test_check_systemd_analyze_verify_obsolete', 'test_check_systemd_analyze_verify_ordering_cycle')):
+        if self.id().endswith(('test_check_systemd_analyze_verify_missing', 'test_check_systemd_analyze_verify_deprecated_unsafe', 'test_check_systemd_analyze_verify_obsolete', 'test_check_systemd_analyze_verify_ordering_cycle', 'test_check_journalctl_service_unknown_lvalue')):
+            check_file = self.utils_dir + '/systemd_analyze_services.sh'
+            check_file_tmp = '/tmp/systemd_analyze_services.sh'
+            if self.params['remote_node'] is not None:
+                cmd = 'ls -l {}'.format(check_file_tmp)
+                ret = utils_lib.run_cmd(self, cmd, ret_status=True, msg='check if {} exists'.format(check_file))
+                if ret != 0:
+                    self.log.info('Copy {} to remote'.format(check_file))
+                    self.SSH.put_file(local_file=check_file, rmt_file=check_file_tmp)
+            else:
+                cmd = 'sudo cp -f {} {}'.format(check_file,check_file_tmp)
+                utils_lib.run_cmd(self, cmd)
+            check_file = check_file_tmp
+            utils_lib.run_cmd(self, 'sudo chmod 755 {}'.format(check_file_tmp))
             self.systemd_analyze_verify_file = '/tmp/{}_systemd_analyze_verify.log'.format(self.run_uuid)
-            output = utils_lib.run_cmd(self, 'cat {}'.format(self.systemd_analyze_verify_file), msg="check if output exists")
-            if 'No such file' in output:
-                services = ['default.target']
-                cmd = "systemctl list-unit-files |grep -v UNIT|grep -v listed|awk -F' ' '{print $1}'"
-                all_services = utils_lib.run_cmd(self, cmd, msg='retrive all systemd unit files').split('\n')
-                for service in all_services:
-                    if not service or service.startswith('-'):
-                        continue
-                    services.append(service)
-                cmd = "sudo systemd-analyze verify {} > {} 2>&1".format(' '.join(services),self.systemd_analyze_verify_file)
-                utils_lib.run_cmd(self, cmd, msg='verify services')
+            cmd = 'sudo bash -c "{} {}"'.format(check_file, self.systemd_analyze_verify_file)
+            output = utils_lib.run_cmd(self, cmd, timeout=240, msg="start analyze......")
+
+    def test_check_trigger_automount(self):
+        """
+        case_name:
+            test_check_trigger_automount
+        component:
+            sysstat
+        bugzilla_id:
+            1670060
+        is_customer_case:
+            True
+        maintainer:
+            xuazhao@redhat.com
+        description:
+            check sysstat not triggering a mount of all automount filesystem and statistic gather even when not selected.
+        key_steps:
+            1. sudo yum install -y sysstat strace
+            2. rm -rf sa.new
+            3. strace -fttT -o sadc.trc /usr/lib64/sa/sadc -F -L 1 2 sa.new
+            4. grep mtab sadc.trc
+        expect_result:
+            no mstab keyword found,eg.17234 13:38:38.058270 open("/etc/mtab", O_RDONLY) = 3 <0.000428>
+        debug_want:
+            version of sysstat
+        """
+        
+        utils_lib.is_pkg_installed(self,'sysstat strace', cancel_case=True)
+
+        cmd = 'rpm -q sysstat'
+        utils_lib.run_cmd(self,cmd)
+
+        cmd = 'rm -rf sa.new'
+        utils_lib.run_cmd(self,cmd,msg='clean old data')
+
+        cmd = 'strace -fttT -o sadc.trc /usr/lib64/sa/sadc -F -L 1 2 sa.new'
+        utils_lib.run_cmd(self,cmd,msg='generate report')
+
+        cmd = 'grep mtab sadc.trc'
+        utils_lib.run_cmd(self,cmd, expect_not_ret=0, msg='check ret')
 
     def test_check_avclog(self):
-        '''
-        polarion_id: N/A
-        '''
-        cmd = "sudo ausearch -m AVC -ts today"
+        """
+        case_name:
+            test_check_avclog
+        component:
+            selinux-policy
+        bugzilla_id:
+            N/A
+        maintainer:
+            xiliang@redhat.com
+        description:
+            test if avc log exist
+        key_steps:
+            sudo ausearch -m AVC -ts today
+        expect_result:
+            no avc log returned
+        debug_want:
+            # rpm -qa selinux\* container\* | sort
+        """
+        cmd = "rpm -qa selinux\* container\* | sort"
+        utils_lib.run_cmd(self, cmd, msg='please attach this log if bug is found')
+        cmd = "sudo ausearch -m AVC -ts today -i"
         utils_lib.run_cmd(self, cmd, expect_not_ret=0, msg='Checking avc log!', rmt_get_pty=True)
 
     def test_check_avclog_nfs(self):
-        '''
-        bz: 1771856
-        polarion_id: N/A
-        '''
+        """
+        case_name:
+            test_check_avclog_nfs
+        component:
+            kernel
+        bugzilla_id:
+            1771856
+        is_customer_case:
+            False
+        maintainer:
+            xiliang@redhat.com
+        description:
+            Check if there's avc log after mounting
+        key_steps:
+            1.check if there's nfs installed
+            2.# systemctl start nfs-server.service
+            3.# mkdir /tmp/testrw
+            4.# chmod -R 777 /tmp/testrw
+            5.# exportfs -o rw,insecure_locks,all_squash,fsid=1 *:/tmp/testrw
+            6.# mount -t nfs 127.0.0.1:/tmp/testrw /mnt
+        expect_result:
+            no new avc log generated
+        debug_want:
+            # rpm -qa selinux\* container\* | sort
+        """
+        cmd = "rpm -qa selinux\* container\* | sort"
+        utils_lib.run_cmd(self, cmd, msg='please attach this log if bug is found')
         time_start = utils_lib.run_cmd(self, "date '+%T'", msg='retrive test system current time')
         self.log.info("Check no permission denied at nfs server - bug1655493")
         utils_lib.is_pkg_installed(self,pkg_name='nfs-utils')
@@ -73,14 +156,37 @@ class TestGeneralCheck(unittest.TestCase):
         utils_lib.run_cmd(self, "sudo umount /mnt")
 
         time.sleep(10)
-        cmd = "sudo ausearch -m AVC -ts today {}".format(time_start)
+        cmd = "sudo ausearch -i -m AVC -ts today {}".format(time_start)
         utils_lib.run_cmd(self, cmd, expect_not_ret=0, msg='check if new avc log generated', rmt_get_pty=True)
 
     def test_check_available_clocksource(self):
-        '''
-        bz: 1726487
-        polarion_id:
-        '''
+        """
+        case_name:
+            test_check_available_clocksource
+        component:
+            kernel
+        bugzilla_id:
+            1726487
+        is_customer_case:
+            False
+        maintainer:
+            xiliang@redhat.com
+        description:
+            Check if there is clocksource in available_clocksource
+        key_steps:
+            1.lscpu
+            2.sudo cat /sys/devices/system/clocksource/clocksource0/available_clocksource
+            3.check available_clocksource
+        expect_result:
+            the clocksource matched to the system is expected.
+            Xen - xen,tsc,hpet,acpi_pm,
+            aarch64 - arch_sys_counter,
+            Microsoft - hyperv_clocksource_tsc_page,acpi_pm,
+            AuthenticAMD - kvm-clock,tsc,acpi_pm,
+            GenuineIntel - kvm-clock,tsc,acpi_pm
+            Others - tsc,hpet,acpi_pm'
+
+        """
         output = utils_lib.run_cmd(self, 'lscpu', expect_ret=0)
         if 'Xen' in output:
             expect_clocks = 'xen,tsc,hpet,acpi_pm'
@@ -104,45 +210,150 @@ available_clocksource'
                     msg='Checking available clocksource')
 
     def test_check_boot_time(self):
-        '''
-        bz: 1776710
-        polarion_id: RHEL7-93100
-        check the boot time.
-        '''
+        """
+        case_name:
+            test_check_boot_time
+        component:
+            rng-tools
+        bugzilla_id:
+            1776710
+        is_customer_case:
+            False
+        maintainer:
+            xiliang@redhat.com
+        description:
+            check if there's boot time delay
+        key_steps:
+            1.check journal log and system bootup time,
+            2.compare the bootup time with max boot time
+        expect_result:
+            real boot time doesn't delay compared to max_boot_time
+        debug_want:
+            journal log
+        """
         max_boot_time = self.params.get('max_boot_time')
         boot_time_sec = utils_lib.getboottime(self)
         utils_lib.compare_nums(self, num1=boot_time_sec, num2=max_boot_time, ratio=0, msg="Compare with cfg specified max_boot_time")
 
     def test_check_dmesg_error(self):
-        '''
-        polarion_id: RHEL7-103851
-        '''
+        """
+        case_name:
+            test_check_dmesg_error
+        component:
+            kernal
+        bugzilla_id:
+            N/A
+        is_customer_case:
+            False
+        testplan:
+            N/A
+        maintainer:
+            xiliang@redhat.com
+        description:
+            check if there are error in dmesg
+        key_steps:
+            dmesg
+        expect_result:
+            no error return
+        debug_want:
+            dmesg
+        """
         utils_lib.check_log(self, 'error', log_cmd='dmesg')
 
     def test_check_dmesg_fail(self):
-        '''
-        polarion_id: RHEL7-103851
-        '''
+        """
+        case_name:
+            test_check_dmesg_fail
+        component:
+            kernal
+        bugzilla_id:
+            N/A
+        is_customer_case:
+            False
+        testplan:
+            N/A
+        maintainer:
+            xiliang@redhat.com
+        description:
+            check if there are fail in dmesg
+        key_steps:
+            dmesg
+        expect_result:
+            no fail return
+        debug_want:
+            dmesg
+        """
         utils_lib.check_log(self, 'fail', log_cmd='dmesg')
 
     def test_check_dmesg_warn(self):
-        '''
-        polarion_id: RHEL7-103851
-        '''
+        """
+        case_name:
+            test_check_dmesg_warn
+        component:
+            kernal
+        bugzilla_id:
+            N/A
+        is_customer_case:
+            False
+        testplan:
+            N/A
+        maintainer:
+            xiliang@redhat.com
+        description:
+            check if there are warn in dmesg
+        key_steps:
+            dmesg
+        expect_result:
+            no warn return
+        debug_want:
+            dmesg
+        """
         utils_lib.check_log(self, 'warn', log_cmd='dmesg')
 
     def test_check_dmesg_unable(self):
-        '''
-        bz: 1779454
-        polarion_id:
-        '''
+        """
+        case_name:
+            test_check_dmesg_unable
+        component:
+            kernel
+        bugzilla_id:
+            1779454
+        is_customer_case:
+            False
+        maintainer:
+            xiliang@redhat.com
+        description:
+            check if there's any unable in dmesg
+        key_steps:
+            ckeck dmesg log
+        expect_result:
+            There's no unable in dmesg log
+        debug_want:
+            dmesg log
+        """
         utils_lib.check_log(self, 'unable', log_cmd='dmesg')
 
     def test_check_dmesg_calltrace(self):
-        '''
-        bz: 1777179
-        polarion_id: RHEL7-103851
-        '''
+        """
+        case_name:
+            test_check_dmesg_calltrace
+        component:
+            kernel
+        bugzilla_id:
+            1777179
+        is_customer_case:
+            False
+        maintainer:
+            xiliang@redhat.com
+        description:
+            Check if there is cal trace in dmesg
+        key_steps:
+            dmesg
+        expect_result:
+            no call trace returned
+        debug_want:
+            dmesg output
+        """
         utils_lib.run_cmd(self, 'dmesg', expect_ret=0, expect_not_kw='Call trace,Call Trace', msg="Check there is no call trace in dmesg")
 
     def test_check_dmesg_unknownsymbol(self):
@@ -229,16 +440,40 @@ available_clocksource'
             No segmentation fault found.
         '''
         utils_lib.is_cmd_exist(self, cmd='dmidecode')
-        cmd = "sudo dmidecode --dump-bin {}/debug/dmidecode_debug.bin".format(self.log_dir)
-        utils_lib.run_cmd(self, cmd, msg='save dmidecode_debug.bin for debug purpose, please attach it if file bug')
+        if self.params['remote_node'] is not None:
+            binfile = '/tmp/dmidecode_debug.bin'
+            cmd = "sudo dmidecode --dump-bin {}".format(binfile)
+            utils_lib.run_cmd(self, cmd, msg='save dmidecode_debug.bin for debug purpose, please attach it if file bug')
+            self.log.info('retrive {} from remote'.format(binfile))
+            self.SSH.get_file(rmt_file=binfile,local_file='{}/debug/dmidecode_debug.bin'.format(self.log_dir))
+        else:
+            cmd = "sudo dmidecode --dump-bin {}/debug/dmidecode_debug.bin".format(self.log_dir)
+            utils_lib.run_cmd(self, cmd, msg='save dmidecode_debug.bin for debug purpose, please attach it if file bug')
         cmd = "sudo dmidecode --dump"
         utils_lib.run_cmd(self, cmd, expect_ret=0, expect_not_kw='Segmentation')
 
     def test_check_dmidecode_outofspec(self):
-        '''
-        bz: 1858350
-        des: make sure there is no "OUT OF SPEC" in dmidecode output
-        '''
+        """
+        case_name:
+            test_check_dmidecode_outofspec
+        component:
+            dmidecode
+        bugzilla_id:
+            1858350
+        maintainer:
+            xiliang@redhat.com
+        is_customer_case:
+            True
+        description:
+            dmidecode command prints "OUT OF SPEC" messages for empty NVMe and DIMM slots
+        key_steps:
+            1.sudo dmidecode --dump-bin {log_dir}/debug/dmidecode_debug.bin
+            2.sudo dmidecode
+        expect_result:
+            It should not print "OUT OF SPEC" in output
+        debug_want:
+            dmidecode_debug.bin
+        """
         utils_lib.is_cmd_exist(self, cmd='dmidecode')
         cmd = "sudo dmidecode --dump-bin {}/debug/dmidecode_debug.bin".format(self.log_dir)
         utils_lib.run_cmd(self, cmd, msg='save dmidecode_debug.bin for debug purpose, please attach it if file bug')
@@ -249,10 +484,31 @@ available_clocksource'
                     msg='Check there is no "OUT OF SPEC" in dmidecode output')
 
     def test_check_cpu_vulnerabilities(self):
-        '''
-        check if cpu has unexpected Vulnerable
-        '''
-
+        """
+        case_name:
+            test_check_cpu_vulnerabilities
+        component:
+            kenel
+        bugzilla_id:
+            N/A
+        is_customer_case:
+            False
+        testplan:
+            N/A
+        maintainer:
+            xiliang@redhat.com
+        description:
+            check if cpu has unexpected Vulnerable
+        key_steps:
+            1.rpm -qa|grep microcode
+            2.rpm -qa|grep linux-firmware
+            3.sudo grep . /sys/devices/system/cpu/vulnerabilities/* | sed 's/:/^/' | column -t -s^
+            4.get cpu vulnerabilities according to server type
+        expect_result:
+            There's no vulnerable returned
+        debug_want:
+            N/A
+        """
         utils_lib.run_cmd(self, "rpm -qa|grep microcode", msg='Get microcode version')
         utils_lib.run_cmd(self, "rpm -qa|grep linux-firmware",msg='get linux-firmware pkg version')
         check_cmd = r"sudo grep . /sys/devices/system/cpu/vulnerabilities/* | \
@@ -263,7 +519,7 @@ sed 's/:/^/' | column -t -s^"
         if utils_lib.is_metal(self):
             self.log.info(
                 "Bare metal instance should not have any vulnerable (microload loaded).")
-            cmd = r"sudo grep . /sys/devices/system/cpu/vulnerabilities/* | \
+            check_cmd = r"sudo grep . /sys/devices/system/cpu/vulnerabilities/* | \
 sed 's/:/^/' | column -t -s^"
         elif 'el7' in output:
             self.log.info(
@@ -372,7 +628,7 @@ itlb_multihit|sed 's/:/^/' | column -t -s^"
             Check "iostat -x" report and make sure there is no high utils when there is no obviously read/write operations.
         key_steps:
             1. # iostat -x
-        expected_result:
+        expected_result: |
             No high utils reported when no obviously read/write operations.
             eg. # iostat -x
                 Linux 4.18.0-236.el8.aarch64 (ip-xx-xxx-x-xxx.us-west-2.compute.internal) 	09/28/2020 	_aarch64_	(2 CPU)
@@ -414,10 +670,26 @@ itlb_multihit|sed 's/:/^/' | column -t -s^"
                                   (util, expect_utils))
 
     def test_check_journal_calltrace(self):
-        '''
-        polarion_id:
-        bz: 1801999, 1736818
-        '''
+        """
+        case_name:
+            test_check_journal_calltrace
+        component:
+            Operations
+        bugzilla_id:
+            1801999,1736818
+        is_customer_case:
+            False
+        maintainer:
+            xiliang@redhat.conm
+        description:
+            Find if there are words like "Traceback","Backtrace" in journal
+        key_steps:
+            Check the journalctl log
+        expect_result:
+            There's no "Traceback"or"Backtrace" in journal, all scripts run without error 
+        debug_want:
+            journalctl log
+        """
         utils_lib.check_log(self, 'Traceback,Backtrace', skip_words='test_check_journal_calltrace', rmt_redirect_stdout=True)
 
     def test_check_journalctl_cannot(self):
@@ -524,18 +796,55 @@ itlb_multihit|sed 's/:/^/' | column -t -s^"
         utils_lib.check_log(self, expect_not_kws, skip_words='test_check_journalctl_disabled', rmt_redirect_stdout=True)
 
     def test_check_journalctl_dumpedcore(self):
-        '''
-        polarion_id:
-        bz: 1797973
-        '''
+        """
+        case_name:
+            test_check_journalctl_dumpedcore
+        component:
+            sssd
+        bugzilla_id:
+            1797973
+        is_customer_case:
+            False
+        maintainer:
+            xiliang@redhat.com
+        description:
+            check if system can enable fips successfully
+        key_steps:
+            1.enable fips and reboot the system.
+            2.dumped core
+        expect_result:
+            no core dump
+        debug_want:
+            redirected output file
+        """
         # redirect journalctl output to a file as it is not get return
         # normally in RHEL7
         utils_lib.check_log(self, 'dumped core', skip_words='test_check_journalctl_dumpedcore', rmt_redirect_stdout=True)
 
     def test_check_journalctl_error(self):
-        '''
-        polarion_id: RHEL7-103851
-        '''
+        """
+        case_name:
+            test_check_journalctl_error
+        component:
+            kernel
+        bugzilla_id:
+            N/A
+        is_customer_case:
+            False
+        testplan:
+            N/A
+        maintainer:
+            xiliang@redhat.com
+        description:
+            check the boot message
+        key_steps:
+            check dmesg
+            check /var/log/mesages
+        expect_result:
+            no unexpected error
+        debug_want:
+            dmesg
+        """
         utils_lib.check_log(self, 'error', skip_words='test_check,UpdateGSErrors', rmt_redirect_stdout=True)
 
     def test_check_journalctl_fail(self):
@@ -613,12 +922,52 @@ itlb_multihit|sed 's/:/^/' | column -t -s^"
         utils_lib.check_log(self, 'unexpected', skip_words='test_check_journalctl_unexpected', rmt_redirect_stdout=True)
 
     def test_check_journalctl_warn(self):
-        '''
-        polarion_id: RHEL7-103851
-        '''
+        """
+        case_name:
+            test_check_journalctl_warn
+        component:
+            kernel
+        bugzilla_id:
+            N/A
+        is_customer_case:
+            False
+        testplan:
+            N/A
+        maintainer:
+            xiliang@redhat.com
+        description:
+            check the boot message
+        key_steps:
+            check dmesg
+            check /var/log/mesages
+        expect_result:
+            no unexpected warn
+        debug_want:
+            dmesg
+        """
         utils_lib.check_log(self, 'warn', skip_words='test_check',rmt_redirect_stdout=True)
 
     def test_check_journalctl_invalid(self):
+        """
+        case_name:
+            test_check_journalctl_invalid
+        component:
+            sg3_utils
+        bugzilla_id:
+            1750417
+        is_customer_case:
+            True
+        maintainer:
+            xiliang@redhat.com
+        description:
+            check if there's invalid in journal log
+        key_steps:
+            check journal log
+        expect_result:
+            no unexpected invalid in journal log
+        debug_want:
+            journal log
+        """
         '''
         polarion_id:
         bz:1750417
@@ -651,15 +1000,7 @@ itlb_multihit|sed 's/:/^/' | column -t -s^"
             - service unit file content
             - output from 'systemd-analyze verify $service'
         """
-        services = ['default.target']
-        cmd = "systemctl list-unit-files |grep -v UNIT|grep -v listed|awk -F' ' '{print $1}'"
-        all_services = utils_lib.run_cmd(self, cmd, msg='retrive all systemd unit files').split('\n')
-        for service in all_services:
-            if not service or service.startswith('-'):
-                continue
-            services.append(service)
-        cmd = "sudo systemd-analyze verify {}".format(' '.join(services))
-        utils_lib.run_cmd(self, cmd, expect_not_kw='Unknown lvalue', msg='Check there is no Unknown lvalue')
+        utils_lib.run_cmd(self, 'cat {}'.format(self.systemd_analyze_verify_file),expect_ret=0, expect_not_kw='Unknown lvalue', msg='Check there is no "Unknown lvalue" keyword')
 
     def test_check_locale(self):
         '''
@@ -683,7 +1024,7 @@ itlb_multihit|sed 's/:/^/' | column -t -s^"
             1. # locale
         expected_result:
             No error information found.
-        debug_want:
+        debug_want: |
             1. # rpm -qa | grep glibc
             2. # uname -r
         '''
@@ -814,14 +1155,30 @@ itlb_multihit|sed 's/:/^/' | column -t -s^"
         self.assertEqual(lspci_out, lsblk_out, msg="No all nvme pci device nvme driver are loaded")
 
     def test_check_meminfo_memfree(self):
-        '''
-        rhbz: 1880090
-        MemFree should less than MemTotal
-        Fail output:
-        # cat /sys/devices/system/node/node0/meminfo
-        Node 0 MemTotal:       30774804 kB
-        Node 0 MemFree:        31505560 kB
-        '''
+        """
+        case_name:
+            test_check_meminfo_memfree
+        component:
+            kernel
+        bugzilla_id:
+            1880090
+        is_customer_case:
+            True
+        testplan:
+            N/A
+        maintainer:check if the numa information is correct
+            xiliang@redhat.com
+        description:
+            check if the numa node memory information is correct
+        key_steps:
+            1.sudo cat /sys/devices/system/node/node0/meminfo
+            2.compare memfree,memtotal and memused
+        expect_result:
+            memfree < memtotal
+            memused < memtotal
+        debug_want:
+            /sys/devices/system/node/node0/meminfo
+        """
         out = utils_lib.run_cmd(self, 'sudo cat /sys/devices/system/node/node0/meminfo', expect_ret=0,
                     msg="Check MemFree less than MemTotal")
         memtotal = re.findall('[\d]+',re.findall('MemTotal:.*[\d]*',out)[0])[0]
@@ -838,9 +1195,29 @@ itlb_multihit|sed 's/:/^/' | column -t -s^"
             self.log.info("memused:{} < memtotal:{}".format(memused, memtotal))
 
     def test_check_memleaks(self):
-        '''
-        polarion_id: RHEL-117648
-        '''
+        """
+        case_name:
+            test_check_memleaks
+        component:
+            kernel
+        bugzilla_id:
+            161666
+        is_customer_case:
+            True
+        testplan:
+            N/A
+        maintainer:
+            xiliang@redhat.com
+        description:
+            check if there are memory leak
+        key_steps:
+            1.sudo echo scan > /sys/kernel/debug/kmemleak
+            2.cat /sys/kernel/debug/kmemleak
+        expect_result:
+            no return
+        debug_want:
+            /sys/kernel/debug/kmemleak
+        """
         self.log.info("Check memory leaks")
         utils_lib.run_cmd(self,
                     'uname -a',
@@ -906,11 +1283,30 @@ itlb_multihit|sed 's/:/^/' | column -t -s^"
             self.fail(f'{command}(pid:{lastpid}) have abnormal usage of Memory.')
 
     def test_check_microcode_load(self):
-        '''
-        bz: 1607899
-        des: Don't attempt to perform early microcode update on virtualized guests
-        This case checks it from dmesg output.
-        '''
+        """
+        case_name:
+            test_check_microcode_load
+        component:
+            kernel
+        bugzilla_id:
+            1607899
+        is_customer_case:
+            False
+        testplan:
+            N/A
+        maintainer:
+            xiliang@redhat.com
+        description:
+            check if microbe performed early update in x86 metal systems
+        key_steps:
+            1.rpm -qa|grep microcode
+            2.rpm -qa|grep linux-firmware
+            3.dmesg|grep microcode
+        expect_result:
+            microcode loaded in metal system and microcode not loaded in virtual system.
+        debug_want:
+            dmesg log
+        """
         cpu_info = utils_lib.run_cmd(self,
                     'lscpu',
                     expect_ret=0,
@@ -931,10 +1327,29 @@ itlb_multihit|sed 's/:/^/' | column -t -s^"
                         msg='microcode should not load in VMs')
 
     def test_check_nouveau(self):
-        '''
-        polarion_id: N/A
-        bz: 1349927, 1645772
-        '''
+        """
+        case_name:
+            test_check_nouveau
+        component:
+            kernel
+        bugzilla_id:
+            1349927, 1645772
+        is_customer_case:
+            False
+        testplan:
+            N/A
+        maintainer:
+            xiliang@redhat.com
+        description:
+            check if nouveau is in blacklist and is not loaded in aws
+        key_steps:
+            lsmod
+            cat /proc/cmdline
+        expect_result:
+            nouveau is no in lsmod and is in blacklist
+        debug_want:
+            lsmod
+        """
         utils_lib.is_aws(self, action='cancel')
         utils_lib.run_cmd(self, 'cat /etc/redhat-release', cancel_not_kw='CentOS', msg='skip this check on centos, rhbz1645772')
         self.log.info("nouveau is not required in ec2, make sure it is \
@@ -951,10 +1366,29 @@ in blacklist and not loaded bug1645772")
                     msg="Checking cmdline")
 
     def test_check_nvme_io_timeout(self):
-        '''
-        polarion_id: N/A
-        bz: 1859088
-        '''
+        """
+        case_name:
+            test_check_nvme_io_timeout
+        component:
+            distribution
+        bugzilla_id:
+            1859088
+        is_customer_case:
+            False
+        testplan:
+            N/A
+        maintainer:
+            xiliang@redhat.com
+        description:
+            check if the nvme_core.io_timeout is 4294967295 in aws
+        key_steps:
+            1.sudo cat /sys/module/nvme_core/parameters/io_timeout
+            2.sudo cat /proc/cmdline
+        expect_result:
+            nvme_core.io_timeout=4294967295
+        debug_want:
+            io_timeout,cmdline
+        """
         utils_lib.is_aws(self, action='cancel')
         self.log.info("nvme_core.io_timeout=4294967295 is recommended in ec2, make sure it is \
 in cmdline as bug1859088")
@@ -968,10 +1402,30 @@ in cmdline as bug1859088")
                     msg="Checking cmdline")
 
     def test_check_release_name(self):
-        '''
-        polarion_id: RHEL7-103850
-        bz: 1852657
-        '''
+        """
+        case_name:
+            test_check_release_name
+        component:
+            ec2-images
+        bugzilla_id:
+            1852657
+        is_customer_case:
+            False
+        testplan:
+            N/A
+        maintainer:
+            xiliang@redhat.com
+        description:
+            check if the release name is correct
+        key_steps:
+            1.cat /etc/redhat-release
+            2.uname -r
+            3.compare real name and true name
+        expect_result:
+            no other release name found and current name is correct
+        debug_want:
+            redhat-release
+        """
         check_cmd = "cat /etc/redhat-release"
         output = utils_lib.run_cmd(self,check_cmd, expect_ret=0, msg='check release name')
         kernel_ver = utils_lib.run_cmd(self, 'uname -r', msg="Get kernel version")
@@ -1024,11 +1478,30 @@ in cmdline as bug1859088")
         utils_lib.check_log(self, 'unknown', log_cmd='uname -r;cat /proc/self/status', msg='Check no unknown in "/proc/self/status"')
 
     def test_check_product_id(self):
-        '''
-        bz: 1938930
-        issue: RHELPLAN-60817
-        check if product id matches /etc/redhat-release
-        '''
+        """
+        case_name:
+            test_check_product_id
+        component:
+            ec2-images
+        bugzilla_id:
+            1938930
+        is_customer_case:
+            False
+        testplan:
+            N/A
+        maintainer:
+            xiliang@redhat.com
+        description:
+            check if product id matches /etc/redhat-release
+        key_steps:
+            1.cat /etc/redhat-release
+            2.rpm -qa|grep redhat-release
+            3.sudo rct cat-cert /etc/pki/product-default/*.pem
+        expect_result:
+            product id matches the one in redhat-release
+        debug_want:
+            /etc/pki/product-default/*.pem
+        """
         check_cmd = "cat /etc/redhat-release"
         output = utils_lib.run_cmd(self,check_cmd, expect_ret=0, cancel_not_kw='CentOS,Fedora', msg='check release name')
         product_id = re.findall('\d.\d', output)[0]
@@ -1218,11 +1691,29 @@ in cmdline as bug1859088")
         utils_lib.run_cmd(self, 'cat {}'.format(self.systemd_analyze_verify_file),expect_ret=0, expect_not_kw='ordering cycle', msg='Check there is no ordering cycle which may block boot up')
 
     def test_check_tsc_deadline_timer(self):
-        '''
-        des: check TSC deadline timer enabled in dmesg
-        bz: 1503160
-        polarion_id: RHEL7-111006
-        '''
+        """
+        case_name:
+            test_check_tsc_deadline_timer
+        component:
+            kernel
+        bugzilla_id:
+            1503160
+        is_customer_case:
+            True
+        maintainer:
+            xiliang@redhat.com
+        description:
+            check if TSC deadline timer enabled in dmesg on intel cpu
+        key_steps:
+            1.lscpu
+            2.grep tsc_deadline_timer /proc/cpuinfo
+            3.dmesg|egrep 'TSC deadline timer enabled|TSC deadline timer available
+            4.sudo cat /sys/devices/system/clockevents/clockevent0/current_device
+        expect_result:
+            deadline timer enabled and current device has lapic-deadline
+        debug_want:
+            current_device
+        """
         utils_lib.run_cmd(self,
                     'lscpu',
                     expect_ret=0,
@@ -1274,11 +1765,31 @@ current_device"
             utils_lib.run_cmd(self, 'tuned-adm active', expect_kw='virtual-guest', msg='Should load virtual-guest in vm by default')
 
     def test_check_virtwhat(self):
-        '''
-        bz: 1782435
-        polarion_id: RHEL7-103857
-        test virt-what, not use systemd-detect-virt
-        '''
+        """
+        case_name:
+            test_check_virtwhat
+        component:
+            virt-what
+        bugzilla_id:
+            1782435
+        is_customer_case:
+            False
+        testplan:
+            N/A
+        maintainer:
+            xiliang@redhat.com
+        description:
+            test if virt-what can run normally
+        key_steps:
+            1.rpm -q virt-what
+            2.sudo virt-what
+            3.lscpu
+            4.compare virt-what result with system type
+        expect_result:
+            virt-what result matchs cpu type without segfault
+        debug_want:
+            N/A
+        """
         utils_lib.is_cmd_exist(self, cmd='virt-what')
         utils_lib.run_cmd(self, "rpm -q virt-what", expect_ret=0, msg='get virt-what version')
         virt_what_output = utils_lib.run_cmd(self, r"sudo virt-what", expect_ret=0)
@@ -1362,9 +1873,29 @@ current_device"
             self.log.info("Found few ({}) differs less than {}".format(count,allow_count))
 
     def test_check_rpm_V_efi(self):
-        '''
-        bz: 1845052
-        '''
+        """
+        case_name:
+            test_check_rpm_V_efi
+        component:
+            efi-rpm-macros
+        bugzilla_id:
+            1845052
+        is_customer_case:
+            True
+        testplan:
+            N/A
+        maintainer:
+            xiliang@redhat.com
+        description:
+            check rpm verify status
+        key_steps:
+            1.sudo rpm -q efi-filesystem
+            2.sudo rpm -V efi-filesystem
+        expect_result:
+            cmd pass without err or fail
+        debug_want:
+            N/A
+        """
         utils_lib.run_cmd(self,
                     'sudo rpm -q efi-filesystem',
                     cancel_not_kw="not installed", msg="check if efi-filesystem is installed")
@@ -1474,7 +2005,30 @@ current_device"
                 self.fail("{} insights rule hit".format(len(tmp_dict)))
         except json.decoder.JSONDecodeError as exc:
             self.log.error("insights rule hit or other unexpected error")
-
+    def test_check_sos_works(self):
+        """
+        case_name:
+            test_check_sos_works
+        component:
+            sos
+        bugzilla_id:
+            1718087
+        is_customer_case:
+            True
+        maintainer:
+            xuazhao@redhat.com
+        description:
+            check if sos report can run without crash
+        key_steps:
+            1.sosreport --batch
+        expect_result:
+            no Traceback in result
+        debug_want:
+            sos_output.txt
+        """
+        utils_lib.is_cmd_exist(self, cmd='sosreport')
+        cmd = "sosreport --batch"
+        utils_lib.run_cmd(self,cmd,expect_ret=0,msg="test sosreport",timeout=120)
     def tearDown(self):
         pass
 
