@@ -1,6 +1,5 @@
 import unittest
 import re
-import os_tests
 from os_tests.libs import utils_lib
 import time
 import os
@@ -11,10 +10,26 @@ class TestGeneralTest(unittest.TestCase):
         self.dmesg_cursor = utils_lib.get_cmd_cursor(self, cmd='dmesg -T')
 
     def test_change_clocksource(self):
-        '''
-        :avocado: tags=test_change_clocksource,fast_check
-        polarion_id:
-        '''
+        """
+        case_name:
+            test_change_clocksource
+        component:
+            kernal
+        bugzilla_id:
+            N/A
+        maintainer:
+            xiliang@redhat.com
+        description:
+            test if can change clock source
+        key_steps:
+            1.sudo cat /sys/devices/system/clocksource/clocksource0/current_clocksource
+            2.sudo cat /sys/devices/system/clocksource/clocksource0/available_clocksource
+            3.sudo bash -c \'echo "%s" > /sys/devices/system/clocksource/clocksource0/current_clocksource
+            4.sudo cat /sys/devices/system/clocksource/clocksource0/current_clocksource
+            5.dmesg|tail -30
+        expect_result:
+            current clock source is changed
+        """
         output = utils_lib.run_cmd(self, 'lscpu', expect_ret=0)
         cmd = 'sudo cat /sys/devices/system/clocksource/clocksource0/\
 current_clocksource'
@@ -41,11 +56,31 @@ current_clocksource'
         utils_lib.run_cmd(self, 'dmesg|tail -30', expect_ret=0)
 
     def test_change_tracer(self):
-        '''
-        no hang/panic happen
-        polarion_id:
-        bz: 1650273
-        '''
+        """
+        case_name:
+            test_change_tracer
+        case_file:
+            https://github.com/liangxiao1/os-tests/blob/8ec8531d5d9e58f5dc2293aa4b2c15fe209d27c6/os_tests/tests/test_general_test.py#L43
+        component:
+            kernel
+        bugzilla_id:
+            1650273
+        maintainer:
+            xiliang@redhat.com
+        description:
+            Test system can switch to available clocksource successfully
+        key_steps:
+            1. install one clean RHEL 8.0 guest, start it.
+            2. # mount -t debugfs nodev /sys/kernel/debug
+            3. # cat /sys/kernel/debug/tracing/available_tracers
+            4. # echo function > /sys/kernel/debug/tracing/current_tracer
+            5. # cat /sys/kernel/debug/tracing/current_tracer
+            6. check the current tracer
+        expect_result:
+            no hang/panic happen after switched clocksource
+        debug_want:
+            test log and full dmesg log
+        """
         cmd = 'sudo mount -t debugfs nodev /sys/kernel/debug'
         utils_lib.run_cmd(self, cmd, msg='mount debugfs')
 
@@ -138,6 +173,27 @@ current_clocksource'
 
 
     def test_fio_cpuclock(self):
+        """
+        case_name:
+            test_fio_cpuclock
+        component:
+            fio
+        bugzilla_id:
+            1943474
+        is_customer_case:
+            False
+        maintainer:
+            xiliang@redhat.com
+        description:
+            test if fio can run normally
+        key_steps:
+            1.check cpu is not aarch64
+            2.sudo fio --cpuclock-test
+        expect_result:
+            pass the test without return
+        debug_want:
+            N/A
+        """
         '''
         bz: 1943474
         polarion_id: N/A
@@ -245,9 +301,7 @@ int main(int argc, char *argv[])
             self.skipTest('skip when mem lower than 4GiB')
         utils_lib.is_cmd_exist(self, cmd='gcc', cancel_case=True)
         utils_lib.is_cmd_exist(self, cmd='wget', cancel_case=True)
-        utils_dir = os.path.realpath(os_tests.__file__)
-        utils_dir = os.path.dirname(utils_dir) + '/utils'
-        redis_src = utils_dir + '/redis_8124.c'
+        redis_src = self.utils_dir + '/redis_8124.c'
         redis_src_tmp = '/tmp/redis_8124.c'
         if self.params['remote_node'] is not None:
             self.log.info('Copy {} to remote'.format(redis_src))
@@ -263,23 +317,59 @@ int main(int argc, char *argv[])
             self.fail("'Your kernel looks fine' not found in {}".format(out))
 
     def test_fsadm_resize(self):
-        '''
-        bz: 1905705
-        polarion_id: N/A
-        fsadm resize should not crash as below without NEW_SIZE specified
-        # fsadm resize $(findmnt -n -o source /)
-        /sbin/fsadm: line 818: $3: unbound variable
-        expected result:
-        fsadm does nothing since the filesystem is already at maximum size
-        '''
+        """
+        case_name:
+            test_fsadm_resize
+        component:
+            lvm2
+        bugzilla_id:
+            1905705
+        is_customer_case:
+            True
+        maintainer:
+            xiliang@redhat.com
+        description:
+            test if "fsdadm resize" can run normally
+        key_steps:
+            1.check cmd fsadm
+            2.sudo fsadm resize $(findmnt -n -o source /)
+        expect_result:
+            fsadm does nothing since the filesystem is already at maximum size
+        """
         utils_lib.is_cmd_exist(self, 'fsadm')
         utils_lib.run_cmd(self, 'sudo fsadm resize $(findmnt -n -o source /)', expect_ret=0,
             expect_not_kw="unbound variable", msg="fsadm should not crash")
 
     def test_subscription_manager_auto(self):
-        '''
-        bz: 1932802, 1905398
-        '''
+        """
+        case_name:
+            test_subscription_manager_auto
+        component:
+            subscription-manager
+        bugzilla_id:
+            1932802, 1905398
+        is_customer_case:
+            <optional: True or False>
+        maintainer:
+            xiliang@redhat.com
+        description:
+            test if subscription-manager can run normally in AWS and Azure, RHEL system without timeout.
+        key_steps:
+            1.sudo subscription-manager config --rhsmcertd.auto_registration=1 --rhsm.manage_repos=0 --rhsmcertd.auto_registration_interval=1
+            2.sudo systemctl restart rhsmcertd
+            3.sudo subscription-manager config
+            4.sudo systemctl is-active rhsmcertd
+            5.sudo cat /var/log/rhsm/rhsmcertd.log
+            6.sudo cat /var/log/rhsm/rhsm.log
+            7.sudo subscription-manager identity
+            8.sudo subscription-manager list --installed
+            9.sudo subscription-manager status
+            10.sudo insights-client --register
+        expect_result:
+            all registration successfully without timeout failure.
+        debug_want:
+            N/A
+        """
         product_name = utils_lib.get_os_release_info(self, field='NAME')
         if 'Red Hat Enterprise Linux' not in product_name:
             self.skipTest('Only for RHEL test.')
@@ -325,6 +415,28 @@ int main(int argc, char *argv[])
             time.sleep(interval)
 
     def test_subscription_manager_config(self):
+        """
+        case_name:
+            test_subscription_manager_config
+        component:
+            subscription-manager
+        bugzilla_id:
+            1862431
+        is_customer_case:
+            True
+        maintainer:
+            xiliang@redhat.com
+        description:
+            check if "subscription-manager config" output equals "subscription-manager config --list" output
+        key_steps:
+            1.sudo subscription-manager config > /tmp/sm_config.log
+            2.sudo subscription-manager config --list > /tmp/sm_config_list.log
+            3.sudo diff -u /tmp/sm_config.log /tmp/sm_config_list.log
+        expect_result:
+            These two configs are same
+        debug_want:
+            sm_config and sm_config_list
+        """
         '''
         bz: 1862431
         des: "subscription-manager config" output should equal "subscription-manager config --list"
@@ -527,10 +639,36 @@ RUN touch /tmp/test.txt
                 self.log.info('no leak found')
 
     def test_podman_rm_stopped(self):
-        '''
-        bz: 1913295
-        des: podman can remove a stopped container
-        '''
+        """
+        case_name:
+            test_podman_rm_stopped
+        component:
+            podman
+        bugzilla_id:
+            1913295
+        is_customer_case:
+            True
+        maintainer:
+            xiliang@redhat.com
+        description:
+            Test podman can remove a stopped container
+        key_steps:
+            1.podman ps -a
+            2.podman rm -a -f
+            3.podman run --name myctr1 -td quay.io/libpod/alpine
+            4.podman run --name myctr2 -td quay.io/libpod/alpine
+            5.timeout 5 podman exec myctr1 sleep 10
+            6.podman kill myctr1
+            7.podman inspect myctr1
+            8.podman rm myctr1
+            9.timeout 5 podman exec myctr2 sleep 10
+            10.podman stop myctr2
+            11.podman inspect myctr2
+            12.podman rm myctr2
+            13.podman ps
+        expect_result:
+            There's no myctr1 and myctr2 left after removing them
+        """
         self.log.info("Test podman can remove a stopped container")
         utils_lib.is_cmd_exist(self, 'podman')
         cmd = "podman ps -a"
@@ -673,10 +811,27 @@ grep -i pci|grep n1' % boot_pci
         utils_lib.check_log(self, "error,warn,fail,trace,Trace", log_cmd='dmesg -T', cursor=self.dmesg_cursor)
 
     def test_xenfs_write_inability(self):
-        '''
-        polarion_id:
-        bz: 1663266
-        '''
+        """
+        case_name:
+            test_xenfs_write_inability
+        component:
+            kernel
+        bugzilla_id:
+            1663266
+        is_customer_case:
+            True
+        maintainer:
+            xiliang@redhat.com
+        description:
+            test xen instance system stability after running specfic python script
+        key_steps:
+            1.use python to run t.py
+            2.dmesg
+        expect_result:
+            no call trace return
+        debug_want:
+            N/A
+        """
         utils_lib.run_cmd(self,
                     'lscpu',
                     expect_ret=0,
