@@ -12,10 +12,26 @@ class TestLifeCycle(unittest.TestCase):
             self.skipTest("Only support to run in server-client mode!")
         if utils_lib.is_metal(self):
             self.ssh_timeout = 1200
+            self.SSH.interval = 60
         else:
             self.ssh_timeout = 180
         self.log.info('set ssh connection timeout to {}'.format(self.ssh_timeout))
 
+        if 'kdump' in self.id():
+            timeout = 120
+            interval = 5
+            time_start = int(time.time())
+            while True:
+               cmd = 'sudo systemctl is-active kdump'
+               ret = utils_lib.run_cmd(self, cmd,ret_status=True, msg='check kdump is active')
+               if ret == 0: break
+               time_end = int(time.time())
+               if time_end - time_start > timeout:
+                  self.log.info('timeout ended: {}'.format(timeout))
+                  break
+               self.log.info('retry after {}s'.format(interval))
+               time.sleep(interval)
+
     def test_boot_debugkernel(self):
         '''
         polarion_id:
@@ -188,6 +204,8 @@ class TestLifeCycle(unittest.TestCase):
 
     def test_reboot_resolve_content(self):
         """
+        case_tag:
+            cloudinit
         case_name:
             test_reboot_resolve_content
         case_file:
@@ -206,7 +224,7 @@ class TestLifeCycle(unittest.TestCase):
             Check /etc/resolv.conf content is regenerated and consistent before and after reboot
         key_steps:
             # sudo cp -f /etc/resolv.conf /etc/resolv.conf.orig
-            # sudo truncate -s0 /etc/resolv.conf
+            # sudo truncate -s0 /etc/resolv.conf (skip in openstack platform)
             # sudo reboot
             # sudo diff -u /etc/resolv.conf /etc/resolv.conf.orig
         expect_result:
@@ -215,15 +233,18 @@ class TestLifeCycle(unittest.TestCase):
             # rpm -q NetworkManager
         """
         utils_lib.run_cmd(self, r'sudo cat /etc/resolv.conf',
-                    expect_ret=0, expect_kw='search,nameserver', msg='check resolv.conf content')
+                    expect_ret=0, expect_kw='nameserver', msg='check resolv.conf content')
         utils_lib.run_cmd(self, r'sudo cp -f /etc/resolv.conf /etc/resolv.conf.orig',
                     expect_ret=0, msg='backup /etc/resolv.conf')
-        utils_lib.run_cmd(self, r'sudo truncate -s0 /etc/resolv.conf',
-                    expect_ret=0, msg='cleanup /etc/resolv.conf')
+        if not utils_lib.is_openstack(self):
+            utils_lib.run_cmd(self, r'sudo truncate -s0 /etc/resolv.conf',
+                        expect_ret=0, msg='cleanup /etc/resolv.conf')
         utils_lib.run_cmd(self, 'sudo reboot', msg='reboot system under test')
         time.sleep(10)
         utils_lib.init_connection(self, timeout=self.ssh_timeout)
 
+        utils_lib.run_cmd(self, r'sudo cat /etc/resolv.conf',
+                    expect_ret=0, expect_kw='nameserver', msg='check content after reboot')
         utils_lib.run_cmd(self, r'sudo diff -u /etc/resolv.conf /etc/resolv.conf.orig',
                     expect_ret=0, msg='check if content identical after reboot')
 
@@ -260,6 +281,87 @@ no plan to fix it in the near future!")
         cmd = r'sudo cat /var/crash/*/vmcore-dmesg.txt|tail -50'
         utils_lib.run_cmd(self, cmd, expect_ret=0, expect_kw='write_sysrq_trigger')
 
+    def test_kdump_fastboot_systemctl_kexec(self):
+        '''
+        description:
+            Test loading kernel via kexec with RHEL.
+        testplan:
+            N/A
+        bugzilla_id: 
+            1758323, 1841578
+        is_customer_case:
+            True
+        maintainer: 
+            xiliang
+        case_priority: 
+            0
+        case_component: 
+            Kdump
+        key_steps:
+            1. Launch an instance with multi kernels installed.
+            2. Load each kernel with command "sudo kexec -l /boot/vmlinuz-$version --initrd=/boot/initramfs-$version.img --reuse-cmdline"
+        pass_criteria: 
+            System shutdown and reboot with the specified kernel version, kernel can be loaded via kexec.
+        '''
+        utils_lib.run_cmd(self,'uname -r', cancel_not_kw='el7,el6', msg='Not full support earlier than el8, skip!')
+        cmd = 'sudo rpm -qa|grep -e "kernel-[0-9]"'
+        output = utils_lib.run_cmd(self, cmd, msg='Get kernel version')
+        kernels_list = output.split('\n')
+        for kernel in kernels_list:
+            if kernel is None or kernel == '' or len(kernel) < 6:
+                continue
+            self.log.info('try to swith {}'.format(kernel))
+            kernel_vmlinuz = "/boot/" + kernel.replace('kernel','vmlinuz')
+            kernel_initramfs = "/boot/" + kernel.replace('kernel','initramfs') + ".img"
+            cmd = "sudo kexec -l %s --initrd=%s --reuse-cmdline" % (kernel_vmlinuz, kernel_initramfs)
+            utils_lib.run_cmd(self, cmd, msg='Switch kernel', expect_ret=0)
+            cmd = "sudo systemctl kexec"
+            utils_lib.run_cmd(self, cmd, msg='fast reboot system')
+            time.sleep(10)
+            self.SSH.create_connection()
+            utils_lib.run_cmd(self, 'uname -r', msg='check kernel', expect_ret=0, expect_kw=kernel[7:])
+
+    def test_kdump_fastboot_kexec_e(self):
+        '''
+        description:
+            Test loading kernel via kexec with RHEL on AWS.
+        testplan:
+            N/A
+        bugzilla_id: 
+            1758323, 1841578
+        is_customer_case:
+            True
+        maintainer: 
+            xiliang
+        case_priority: 
+            0
+        case_component: 
+            Kdump
+        key_steps:
+            1. Launch an instance with multi kernels installed.
+            2. Load each kernel with command "sudo kexec -l /boot/vmlinuz-$version --initrd=/boot/initramfs-$version.img --reuse-cmdline"
+            3. When the kernel is loaded, run command "sudo kexec -e".
+        pass_criteria: 
+            Kernel can be loaded via kexec, and system will reboot into the loaded kernel via kexec -e without calling shutdown(8).
+        '''
+        utils_lib.run_cmd(self,'uname -r', cancel_not_kw='el7,el6', msg='Not full support earlier than el8, skip!')
+        cmd = 'sudo rpm -qa|grep -e "kernel-[0-9]"'
+        output = utils_lib.run_cmd(self, cmd, msg='Get kernel version')
+        kernels_list = output.split('\n')
+        for kernel in kernels_list:
+            if kernel is None or kernel == '' or len(kernel) < 6:
+                continue
+            self.log.info('try to swith {}'.format(kernel))
+            kernel_vmlinuz = "/boot/" + kernel.replace('kernel','vmlinuz')
+            kernel_initramfs = "/boot/" + kernel.replace('kernel','initramfs') + ".img"
+            cmd = "sudo kexec -l %s --initrd=%s --reuse-cmdline" % (kernel_vmlinuz, kernel_initramfs)
+            utils_lib.run_cmd(self, cmd, msg='Switch kernel', expect_ret=0)
+            cmd = "sudo kexec -e"
+            utils_lib.run_cmd(self, cmd, msg='fast reboot system')
+            time.sleep(10)
+            self.SSH.create_connection()
+            utils_lib.run_cmd(self, 'uname -r', msg='check kernel', expect_ret=0, expect_kw=kernel[7:])
+
     def tearDown(self):
         reboot_require = False
         if 'test_boot_debugkernel' in self.id():
